"""
Icon.py
by Jason Conti
February 22, 2010

Utility functions for working with icons.
"""

import gc
import gtk
import logging

icon_cache = {}
logger = logging.getLogger("Icon")

def clear_icon_cache():
  """Clear the icon cache, garbage collecting all the icons."""
  global icon_cache
  for key, icon in icon_cache:
    del icon
  icon_cache = {}
  gc.collect()

def load_icon(name, size = 48):
  """Loads an icon from the default icon theme."""
  global icon_cache
  if (name, size) in icon_cache:
    return icon_cache[(name, size)]
  else:
    try:
      theme = gtk.icon_theme_get_default()
      icon = theme.load_icon(name, size, gtk.ICON_LOOKUP_FORCE_SVG)
      icon_cache[(name, size)] = icon
      return icon
    except:
      logger.exception("failed to load_icon")
      return None

def load_icon_from_file(path, size = 48):
  """Loads an icon from the given path."""
  global icon_cache
  if (path, size) in icon_cache:
    return icon_cache[(path, size)]
  else:
    try:
      icon = gtk.gdk.pixbuf_new_from_file_at_size(path, size, size)
      icon_cache[(path, size)] = icon
      return icon
    except:
      logger.exception("failed to load_icon_from_file")
      return None

