"""
ImageToggleButton.py
August 29, 2010

A simple gtk widget for a clickable image.
"""

import glib
import gnomeapplet
import gobject
import gtk
import logging

logger = logging.getLogger("ImageToggleButton")

class ImageToggleButton(gtk.EventBox):
  __gsignals__ = {
      "toggled": (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ())
  }
  def __init__(self):
    gtk.EventBox.__init__(self)
    self.set_selected(False)
    self.connect("button-press-event", self.on_button_press)
    self.connect("button-release-event", self.on_button_release)

    self._toggled = False

    self._press_x = -1
    self._press_y = -1

    self._image = gtk.Image()
    self.set_orient(gnomeapplet.ORIENT_DOWN)
    self.add(self._image)

  def get_active(self):
    return self._toggled

  def get_pixbuf(self):
    return self._image.get_pixbuf()

  def set_from_pixbuf(self, pixbuf):
    self._image.set_from_pixbuf(pixbuf)

  def is_inside(self, x, y):
    alloc = self.get_allocation()
    return x >= 0 and y >= 0 and x <= alloc.width and y <= alloc.height

  def set_orient(self, orient):
    if orient in (gnomeapplet.ORIENT_RIGHT, gnomeapplet.ORIENT_LEFT):
      self._image.set_padding(0, 5)
    else:
      self._image.set_padding(5, 0)

  def set_selected(self, selected):
    if selected:
      self.set_state(gtk.STATE_SELECTED)
      self.set_visible_window(True)
    else:
      self.set_state(gtk.STATE_NORMAL)
      self.set_visible_window(False)

  def on_button_press(self, widget, event):
    if event.button == 1:
      if self.is_inside(event.x, event.y):
        self._press_x = event.x
        self._press_y = event.y
        return True

    return False

  def on_button_release(self, widget, event):
    if event.button == 1:
      if self.is_inside(event.x, event.y) and self.is_inside(self._press_x, self._press_y):
        self._toggled = not self._toggled
        self.set_selected(self._toggled)
        glib.idle_add(self.emit, "toggled")
        return True

    self._press_x = -1
    self._press_y = -1
    return False

